@@ -156,17 +156,11 @@ class HTTPClient(object):
             raise exc.CommunicationError(message=message)
 
         body_iter = ResponseBodyIterator(resp)
-
-        # Read body into string if it isn't obviously image data
-        if resp.getheader('content-type', None) != 'application/octet-stream':
-            body_str = ''.join([chunk for chunk in body_iter])
-            self.log_http_response(resp, body_str)
-            body_iter = StringIO.StringIO(body_str)
-        else:
-            self.log_http_response(resp)
+        body_str = ''.join([chunk for chunk in body_iter])
+        self.log_http_response(resp, body_str)
 
         if 400 <= resp.status < 600:
-            raise exc.from_response(resp, body_iter)
+            raise exc.from_response(resp, body_str)
         elif resp.status in (301, 302, 305):
             # Redirected. Reissue the request to the new location.
             location = resp.getheader('location', None)
@@ -181,9 +175,9 @@ class HTTPClient(object):
                 raise exc.InvalidEndpoint(message=message)
             return self._http_request(location, method, **kwargs)
         elif resp.status == 300:
-            raise exc.from_response(resp, body_iter)
+            raise exc.from_response(resp, body_str)
 
-        return resp, body_iter
+        return resp, body_str
 
     def json_request(self, method, url, **kwargs):
         kwargs.setdefault('headers', {})
@@ -193,10 +187,10 @@ class HTTPClient(object):
         if 'body' in kwargs:
             kwargs['body'] = json.dumps(kwargs['body'])
 
-        resp, body_iter = self._http_request(url, method, **kwargs)
+        resp, body_str = self._http_request(url, method, **kwargs)
 
         if 'application/json' in resp.getheader('content-type', None):
-            body = ''.join([chunk for chunk in body_iter])
+            body = body_str
             try:
                 body = json.loads(body)
             except ValueError:
