@@ -51,8 +51,8 @@ def _set_template_fields(hc, args, fields):
 @utils.arg('-c', '--create-timeout', metavar='<TIMEOUT>',
            default=60, type=int,
            help='Stack creation timeout in minutes. Default: 60')
-@utils.arg('-D', '--disable-rollback', default=False, action="store_true",
-           help='Disable rollback on create/update failure')
+@utils.arg('-r', '--enable-rollback', default=False, action="store_true",
+           help='Enable rollback on create/update failure')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Parameter values used to create the stack.')
 @utils.arg('name', metavar='<STACK_NAME>',
@@ -71,8 +71,8 @@ def do_create(hc, args):
 @utils.arg('-c', '--create-timeout', metavar='<TIMEOUT>',
            default=60, type=int,
            help='Stack creation timeout in minutes. Default: 60')
-@utils.arg('-D', '--disable-rollback', default=False, action="store_true",
-           help='Disable rollback on create/update failure')
+@utils.arg('-r', '--enable-rollback', default=False, action="store_true",
+           help='Enable rollback on create/update failure')
 @utils.arg('-P', '--parameters', metavar='<KEY1=VALUE1;KEY2=VALUE2...>',
            help='Parameter values used to create the stack.')
 @utils.arg('name', metavar='<STACK_NAME>',
@@ -81,7 +81,7 @@ def do_stack_create(hc, args):
     '''Create the stack'''
     fields = {'stack_name': args.name,
               'timeout_mins': args.create_timeout,
-              'disable_rollback': args.disable_rollback,
+              'disable_rollback': not(args.enable_rollback),
               'parameters': utils.format_parameters(args.parameters)}
     _set_template_fields(hc, args, fields)
 
@@ -182,9 +182,8 @@ def do_stack_list(hc, args={}):
     '''List the user's stacks'''
     kwargs = {}
     stacks = hc.stacks.list(**kwargs)
-    field_labels = ['ID', 'Name', 'Status', 'Created']
     fields = ['id', 'stack_name', 'stack_status', 'creation_time']
-    utils.print_list(stacks, fields, field_labels, sortby=3)
+    utils.print_list(stacks, fields, sortby=3)
 
 
 @utils.arg('id', metavar='<NAME or ID>',
@@ -247,11 +246,9 @@ def do_resource_list(hc, args):
     except exc.HTTPNotFound:
         raise exc.CommandError('Stack not found: %s' % args.id)
     else:
-        field_labels = ['Name', 'Type',
-                        'Status', 'Updated']
         fields = ['logical_resource_id', 'resource_type',
                   'resource_status', 'updated_time']
-        utils.print_list(resources, fields, field_labels, sortby=3)
+        utils.print_list(resources, fields, sortby=3)
 
 
 @utils.arg('id', metavar='<NAME or ID>',
@@ -294,13 +291,12 @@ def do_resource_metadata(hc, args):
     fields = {'stack_id': args.id,
               'resource_name': args.resource}
     try:
-        resource = hc.resources.metadata(**fields)
+        metadata = hc.resources.metadata(**fields)
     except exc.HTTPNotFound:
         raise exc.CommandError('Stack or resource not found: %s %s' %
             (args.id, args.resource))
     else:
-        formatters = {}
-        utils.print_dict(resource.to_dict(), formatters=formatters)
+        print json.dumps(metadata, indent=2)
 
 
 @utils.arg('id', metavar='<NAME or ID>',
@@ -316,11 +312,9 @@ def do_event_list(hc, args):
     except exc.HTTPNotFound:
         raise exc.CommandError('Stack not found: %s' % args.id)
     else:
-        field_labels = ['Resource', 'ID', 'Reason',
-                        'Status', 'Event time']
         fields = ['logical_resource_id', 'id', 'resource_status_reason',
                   'resource_status', 'event_time']
-        utils.print_list(events, fields, field_labels, sortby=4)
+        utils.print_list(events, fields, sortby=4)
 
 
 @utils.arg('id', metavar='<NAME or ID>',
